@@ -1,4 +1,7 @@
 <?php
+    /*
+     * $Id: view_as_html.php,v 1.3 2003/10/15 04:27:33 indiri69 Exp $
+     */
     require_once(SM_PATH . 'functions/global.php');
 
     function view_as_html_set() {
@@ -33,21 +36,31 @@
 
     function view_as_html_link() {
         global $message, $show_html_default, $sort;
+        $vars = array('passed_ent_id', 'show_more', 'override_type0', 'override_type1');
 
-        sqgetGlobalVar('mailbox',       $mailbox);
-        sqgetGlobalVar('passed_id',     $passed_id);
-        sqgetGlobalVar('passed_ent_id', $passed_ent_id);
-        sqgetGlobalVar('startMessage',  $startMessage);
-        sqgetGlobalVar('show_more',     $show_more);
-        sqgetGlobalVar('view_as_html',  $view_as_html);
+        sqgetGlobalVar('mailbox',      $mailbox);
+        sqgetGlobalVar('passed_id',    $passed_id);
+        sqgetGlobalVar('startMessage', $startMessage);
+        sqgetGlobalVar('view_as_html', $view_as_html);
 
-        $new_link = "read_body.php?passed_id=$passed_id&amp;mailbox=$mailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=$show_more";
+        $new_link = "read_body.php?passed_id=$passed_id&amp;startMessage=$startMessage" .
+                    "&amp;mailbox=" .  urlencode($mailbox);
 
+        foreach($vars as $var) {
+            if(sqgetGlobalVar($var, $$var))
+                $new_link .= '&amp;' . $var . '=' . $$var;
+        }
         $has_html = 0;
-        if ($message->header->type0 == 'multipart' &&
-            ($message->header->type1 == 'alternative' ||
-             $message->header->type1 == 'mixed' ||
-             $message->header->type1 == 'related')) {
+
+        if ($message->header->type0 == 'message' && $message->header->type1 == 'rfc822') {
+            $type0 = $message->rfc822_header->content_type->type0;
+            $type1 = $message->rfc822_header->content_type->type1;
+        } else {
+            $type0 = $message->header->type0;
+            $type1 = $message->header->type1;
+        }
+        if($type0 == 'multipart' &&
+           ($type1 == 'alternative' || $type1 == 'mixed' || $type1 == 'related')) {
             if ($message->findDisplayEntity(array(), array('text/html'), true)) {
                 $has_html = 1;
             }
@@ -56,7 +69,7 @@
          * Normal single part message so check its type.
          */
         else {
-            if($message->header->type0 == 'text' && $message->header->type1 == 'html') {
+            if($type0 == 'text' && $type1 == 'html') {
                 $has_html = 1;
             }
         }
@@ -68,13 +81,11 @@
             if($show_html_default == 1) {
                 echo "<a href=\"$new_link&amp;view_as_html=0\">";
                 echo _("View as plain text");
-                echo "</a>\n";
-            }
-            else {
+            } else {
                 echo "<a href=\"$new_link&amp;view_as_html=1\">";
                 echo _("View as HTML");
-                echo "</a>\n";
             }
+            echo "</a>\n";
             bindtextdomain('squirrelmail', SM_PATH . 'locale');
             textdomain('squirrelmail');
         }
